@@ -35,14 +35,14 @@
 #include <math.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#ifdef WIN32
+#ifdef _WIN32
 #include <io.h>
 #include <getopt.h>
 #else
 #include <unistd.h>
 #endif
 
-#ifdef LINUX
+#ifdef __linux__
 #include <endian.h>
 #if __BYTE_ORDER == __BIG_ENDIAN
 #define WORDS_BIG_ENDIAN 1
